# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron_sdk_py/proto/core/contract/shield_contract.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'tron_sdk_py/proto/core/contract/shield_contract.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5tron_sdk_py/proto/core/contract/shield_contract.proto\x12\x08protocol\"#\n\x12\x41uthenticationPath\x12\r\n\x05value\x18\x01 \x03(\x08\"c\n\nMerklePath\x12:\n\x14\x61uthentication_paths\x18\x01 \x03(\x0b\x32\x1c.protocol.AuthenticationPath\x12\r\n\x05index\x18\x02 \x03(\x08\x12\n\n\x02rt\x18\x03 \x01(\x0c\"*\n\x0bOutputPoint\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\r\n\x05index\x18\x02 \x01(\x05\"O\n\x0fOutputPointInfo\x12)\n\nout_points\x18\x01 \x03(\x0b\x32\x15.protocol.OutputPoint\x12\x11\n\tblock_num\x18\x02 \x01(\x05\"\x1f\n\x0cPedersenHash\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\x8d\x01\n\x15IncrementalMerkleTree\x12$\n\x04left\x18\x01 \x01(\x0b\x32\x16.protocol.PedersenHash\x12%\n\x05right\x18\x02 \x01(\x0b\x32\x16.protocol.PedersenHash\x12\'\n\x07parents\x18\x03 \x03(\x0b\x32\x16.protocol.PedersenHash\"\xf1\x01\n\x18IncrementalMerkleVoucher\x12-\n\x04tree\x18\x01 \x01(\x0b\x32\x1f.protocol.IncrementalMerkleTree\x12&\n\x06\x66illed\x18\x02 \x03(\x0b\x32\x16.protocol.PedersenHash\x12/\n\x06\x63ursor\x18\x03 \x01(\x0b\x32\x1f.protocol.IncrementalMerkleTree\x12\x14\n\x0c\x63ursor_depth\x18\x04 \x01(\x03\x12\n\n\x02rt\x18\x05 \x01(\x0c\x12+\n\x0coutput_point\x18\n \x01(\x0b\x32\x15.protocol.OutputPoint\"c\n\x1cIncrementalMerkleVoucherInfo\x12\x34\n\x08vouchers\x18\x01 \x03(\x0b\x32\".protocol.IncrementalMerkleVoucher\x12\r\n\x05paths\x18\x02 \x03(\x0c\"\x8f\x01\n\x10SpendDescription\x12\x18\n\x10value_commitment\x18\x01 \x01(\x0c\x12\x0e\n\x06\x61nchor\x18\x02 \x01(\x0c\x12\x11\n\tnullifier\x18\x03 \x01(\x0c\x12\n\n\x02rk\x18\x04 \x01(\x0c\x12\x0f\n\x07zkproof\x18\x05 \x01(\x0c\x12!\n\x19spend_authority_signature\x18\x06 \x01(\x0c\"\x83\x01\n\x12ReceiveDescription\x12\x18\n\x10value_commitment\x18\x01 \x01(\x0c\x12\x17\n\x0fnote_commitment\x18\x02 \x01(\x0c\x12\x0b\n\x03\x65pk\x18\x03 \x01(\x0c\x12\r\n\x05\x63_enc\x18\x04 \x01(\x0c\x12\r\n\x05\x63_out\x18\x05 \x01(\x0c\x12\x0f\n\x07zkproof\x18\x06 \x01(\x0c\"\x91\x02\n\x18ShieldedTransferContract\x12 \n\x18transparent_from_address\x18\x01 \x01(\x0c\x12\x13\n\x0b\x66rom_amount\x18\x02 \x01(\x03\x12\x35\n\x11spend_description\x18\x03 \x03(\x0b\x32\x1a.protocol.SpendDescription\x12\x39\n\x13receive_description\x18\x04 \x03(\x0b\x32\x1c.protocol.ReceiveDescription\x12\x19\n\x11\x62inding_signature\x18\x05 \x01(\x0c\x12\x1e\n\x16transparent_to_address\x18\x06 \x01(\x0c\x12\x11\n\tto_amount\x18\x07 \x01(\x03\x42\x45\n\x18org.tron.protos.contractZ)github.com/tronprotocol/grpc-gateway/coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron_sdk_py.proto.core.contract.shield_contract_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.tron.protos.contractZ)github.com/tronprotocol/grpc-gateway/core'
  _globals['_AUTHENTICATIONPATH']._serialized_start=67
  _globals['_AUTHENTICATIONPATH']._serialized_end=102
  _globals['_MERKLEPATH']._serialized_start=104
  _globals['_MERKLEPATH']._serialized_end=203
  _globals['_OUTPUTPOINT']._serialized_start=205
  _globals['_OUTPUTPOINT']._serialized_end=247
  _globals['_OUTPUTPOINTINFO']._serialized_start=249
  _globals['_OUTPUTPOINTINFO']._serialized_end=328
  _globals['_PEDERSENHASH']._serialized_start=330
  _globals['_PEDERSENHASH']._serialized_end=361
  _globals['_INCREMENTALMERKLETREE']._serialized_start=364
  _globals['_INCREMENTALMERKLETREE']._serialized_end=505
  _globals['_INCREMENTALMERKLEVOUCHER']._serialized_start=508
  _globals['_INCREMENTALMERKLEVOUCHER']._serialized_end=749
  _globals['_INCREMENTALMERKLEVOUCHERINFO']._serialized_start=751
  _globals['_INCREMENTALMERKLEVOUCHERINFO']._serialized_end=850
  _globals['_SPENDDESCRIPTION']._serialized_start=853
  _globals['_SPENDDESCRIPTION']._serialized_end=996
  _globals['_RECEIVEDESCRIPTION']._serialized_start=999
  _globals['_RECEIVEDESCRIPTION']._serialized_end=1130
  _globals['_SHIELDEDTRANSFERCONTRACT']._serialized_start=1133
  _globals['_SHIELDEDTRANSFERCONTRACT']._serialized_end=1406
# @@protoc_insertion_point(module_scope)



from typing import Union
import grpc

from tron_sdk_py.proto.api.api_pb2_grpc import WalletStub, WalletSolidityStub
from tron_sdk_py.proto.api.api_pb2 import EmptyMessage

from tron_sdk_py.proto.core.Tron_pb2 import Transaction
from tron_sdk_py.proto.api.api_pb2 import TransactionExtention

from tron_sdk_py.types import ADDR, HEX
from tron_sdk_py.keys import private_key_to_address, sign_message


class TronClient(object):
    def __init__(self, private_key=None, endpoint="grpc.trongrid.io:50051", solidity_endpoint="grpc.trongrid.io:50061"):
        channel = grpc.insecure_channel(endpoint)
        self.wallet_stub = WalletStub(channel)

        channel = grpc.insecure_channel(solidity_endpoint)
        self.solidity_stub = WalletSolidityStub(channel)

        self.private_key = private_key
        self.address = None

        if self.private_key:
            self.address = private_key_to_address(self.private_key)

    @classmethod
    def mainnet(cls, private_key=None):
        return cls(private_key)

    @classmethod
    def shasta(cls, private_key=None):
        return cls(
            private_key, endpoint="grpc.shasta.trongrid.io:50051", solidity_endpoint="grpc.shasta.trongrid.io:50061"
        )

    @classmethod
    def nile(cls, private_key=None):
        return cls(private_key, endpoint="grpc.nile.trongrid.io:50051", solidity_endpoint="grpc.nile.trongrid.io:50061")

    def sign(self, txn: Union[Transaction, TransactionExtention]) -> Transaction:
        if not self.private_key:
            raise ValueError("private key is not set")
        if isinstance(txn, TransactionExtention):
            txn = txn.transaction

        msg = txn.raw_data.SerializeToString()
        signature = sign_message(self.private_key, msg)
        txn.signature.append(signature)

        return txn


if __name__ == "__main__":
    from tron_sdk_py.proto.core.contract_pb2 import TransferContract

    client = TronClient.nile(private_key=HEX('3333333333333333333333333333333333333333333333333333333333333333'))
    req = TransferContract()
    req.owner_address = ADDR("TJRabPrwbZy45sbavfcjinPJC18kjpRTv8")
    req.to_address = ADDR("TRsbuxREXKJKonexpejWhacE4sYHt1BSHV")
    req.amount = 1_100_000
    txn = client.wallet_stub.CreateTransaction2(req)

    print("TXID:", HEX(txn.txid))

    signed_txn = client.sign(txn)

    print(signed_txn)

    resp = client.wallet_stub.BroadcastTransaction(signed_txn)

    print(resp)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron_sdk_py/proto/core/Discover.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'tron_sdk_py/proto/core/Discover.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%tron_sdk_py/proto/core/Discover.proto\x12\x08protocol\"N\n\x08\x45ndpoint\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x0e\n\x06nodeId\x18\x03 \x01(\x0c\x12\x13\n\x0b\x61\x64\x64ressIpv6\x18\x04 \x01(\x0c\"s\n\x0bPingMessage\x12 \n\x04\x66rom\x18\x01 \x01(\x0b\x32\x12.protocol.Endpoint\x12\x1e\n\x02to\x18\x02 \x01(\x0b\x32\x12.protocol.Endpoint\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\"P\n\x0bPongMessage\x12 \n\x04\x66rom\x18\x01 \x01(\x0b\x32\x12.protocol.Endpoint\x12\x0c\n\x04\x65\x63ho\x18\x02 \x01(\x05\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"W\n\x0e\x46indNeighbours\x12 \n\x04\x66rom\x18\x01 \x01(\x0b\x32\x12.protocol.Endpoint\x12\x10\n\x08targetId\x18\x02 \x01(\x0c\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"i\n\nNeighbours\x12 \n\x04\x66rom\x18\x01 \x01(\x0b\x32\x12.protocol.Endpoint\x12&\n\nneighbours\x18\x02 \x03(\x0b\x32\x12.protocol.Endpoint\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"/\n\rBackupMessage\x12\x0c\n\x04\x66lag\x18\x01 \x01(\x08\x12\x10\n\x08priority\x18\x02 \x01(\x05\x42\x46\n\x0forg.tron.protosB\x08\x44iscoverZ)github.com/tronprotocol/grpc-gateway/coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron_sdk_py.proto.core.Discover_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017org.tron.protosB\010DiscoverZ)github.com/tronprotocol/grpc-gateway/core'
  _globals['_ENDPOINT']._serialized_start=51
  _globals['_ENDPOINT']._serialized_end=129
  _globals['_PINGMESSAGE']._serialized_start=131
  _globals['_PINGMESSAGE']._serialized_end=246
  _globals['_PONGMESSAGE']._serialized_start=248
  _globals['_PONGMESSAGE']._serialized_end=328
  _globals['_FINDNEIGHBOURS']._serialized_start=330
  _globals['_FINDNEIGHBOURS']._serialized_end=417
  _globals['_NEIGHBOURS']._serialized_start=419
  _globals['_NEIGHBOURS']._serialized_end=524
  _globals['_BACKUPMESSAGE']._serialized_start=526
  _globals['_BACKUPMESSAGE']._serialized_end=573
# @@protoc_insertion_point(module_scope)



from Crypto.Hash import keccak
import hashlib


def keccak256(data: bytes) -> bytes:
    hasher = keccak.new(digest_bits=256)
    hasher.update(data)
    return hasher.digest()


def sha256(data: bytes) -> bytes:
    hasher = hashlib.sha256()
    hasher.update(data)
    return hasher.digest()


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron_sdk_py/proto/core/Tron.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'tron_sdk_py/proto/core/Tron.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from tron_sdk_py.proto.core import Discover_pb2 as tron__sdk__py_dot_proto_dot_core_dot_Discover__pb2
from tron_sdk_py.proto.core.contract import common_pb2 as tron__sdk__py_dot_proto_dot_core_dot_contract_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!tron_sdk_py/proto/core/Tron.proto\x12\x08protocol\x1a\x19google/protobuf/any.proto\x1a%tron_sdk_py/proto/core/Discover.proto\x1a,tron_sdk_py/proto/core/contract/common.proto\"*\n\tAccountId\x12\x0c\n\x04name\x18\x01 \x01(\x0c\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0c\"0\n\x04Vote\x12\x14\n\x0cvote_address\x18\x01 \x01(\x0c\x12\x12\n\nvote_count\x18\x02 \x01(\x03\"\xd1\x02\n\x08Proposal\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x03\x12\x18\n\x10proposer_address\x18\x02 \x01(\x0c\x12\x36\n\nparameters\x18\x03 \x03(\x0b\x32\".protocol.Proposal.ParametersEntry\x12\x17\n\x0f\x65xpiration_time\x18\x04 \x01(\x03\x12\x13\n\x0b\x63reate_time\x18\x05 \x01(\x03\x12\x11\n\tapprovals\x18\x06 \x03(\x0c\x12\'\n\x05state\x18\x07 \x01(\x0e\x32\x18.protocol.Proposal.State\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"A\n\x05State\x12\x0b\n\x07PENDING\x10\x00\x12\x0f\n\x0b\x44ISAPPROVED\x10\x01\x12\x0c\n\x08\x41PPROVED\x10\x02\x12\x0c\n\x08\x43\x41NCELED\x10\x03\"\xb9\x01\n\x08\x45xchange\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\x03\x12\x17\n\x0f\x63reator_address\x18\x02 \x01(\x0c\x12\x13\n\x0b\x63reate_time\x18\x03 \x01(\x03\x12\x16\n\x0e\x66irst_token_id\x18\x06 \x01(\x0c\x12\x1b\n\x13\x66irst_token_balance\x18\x07 \x01(\x03\x12\x17\n\x0fsecond_token_id\x18\x08 \x01(\x0c\x12\x1c\n\x14second_token_balance\x18\t \x01(\x03\"\xf2\x02\n\x0bMarketOrder\x12\x10\n\x08order_id\x18\x01 \x01(\x0c\x12\x15\n\rowner_address\x18\x02 \x01(\x0c\x12\x13\n\x0b\x63reate_time\x18\x03 \x01(\x03\x12\x15\n\rsell_token_id\x18\x04 \x01(\x0c\x12\x1b\n\x13sell_token_quantity\x18\x05 \x01(\x03\x12\x14\n\x0c\x62uy_token_id\x18\x06 \x01(\x0c\x12\x1a\n\x12\x62uy_token_quantity\x18\x07 \x01(\x03\x12\"\n\x1asell_token_quantity_remain\x18\t \x01(\x03\x12\"\n\x1asell_token_quantity_return\x18\n \x01(\x03\x12*\n\x05state\x18\x0b \x01(\x0e\x32\x1b.protocol.MarketOrder.State\x12\x0c\n\x04prev\x18\x0c \x01(\x0c\x12\x0c\n\x04next\x18\r \x01(\x0c\"/\n\x05State\x12\n\n\x06\x41\x43TIVE\x10\x00\x12\x0c\n\x08INACTIVE\x10\x01\x12\x0c\n\x08\x43\x41NCELED\x10\x02\"8\n\x0fMarketOrderList\x12%\n\x06orders\x18\x01 \x03(\x0b\x32\x15.protocol.MarketOrder\"C\n\x13MarketOrderPairList\x12,\n\torderPair\x18\x01 \x03(\x0b\x32\x19.protocol.MarketOrderPair\">\n\x0fMarketOrderPair\x12\x15\n\rsell_token_id\x18\x01 \x01(\x0c\x12\x14\n\x0c\x62uy_token_id\x18\x02 \x01(\x0c\"_\n\x12MarketAccountOrder\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x0e\n\x06orders\x18\x02 \x03(\x0c\x12\r\n\x05\x63ount\x18\x03 \x01(\x03\x12\x13\n\x0btotal_count\x18\x04 \x01(\x03\"F\n\x0bMarketPrice\x12\x1b\n\x13sell_token_quantity\x18\x01 \x01(\x03\x12\x1a\n\x12\x62uy_token_quantity\x18\x02 \x01(\x03\"e\n\x0fMarketPriceList\x12\x15\n\rsell_token_id\x18\x01 \x01(\x0c\x12\x14\n\x0c\x62uy_token_id\x18\x02 \x01(\x0c\x12%\n\x06prices\x18\x03 \x03(\x0b\x32\x15.protocol.MarketPrice\"/\n\x11MarketOrderIdList\x12\x0c\n\x04head\x18\x01 \x01(\x0c\x12\x0c\n\x04tail\x18\x02 \x01(\x0c\"\x81\x01\n\x0f\x43hainParameters\x12@\n\x0e\x63hainParameter\x18\x01 \x03(\x0b\x32(.protocol.ChainParameters.ChainParameter\x1a,\n\x0e\x43hainParameter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03\"\xa4\x15\n\x07\x41\x63\x63ount\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\x0c\x12#\n\x04type\x18\x02 \x01(\x0e\x32\x15.protocol.AccountType\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0c\x12\x0f\n\x07\x62\x61lance\x18\x04 \x01(\x03\x12\x1d\n\x05votes\x18\x05 \x03(\x0b\x32\x0e.protocol.Vote\x12+\n\x05\x61sset\x18\x06 \x03(\x0b\x32\x1c.protocol.Account.AssetEntry\x12/\n\x07\x61ssetV2\x18\x38 \x03(\x0b\x32\x1e.protocol.Account.AssetV2Entry\x12(\n\x06\x66rozen\x18\x07 \x03(\x0b\x32\x18.protocol.Account.Frozen\x12\x11\n\tnet_usage\x18\x08 \x01(\x03\x12\x37\n/acquired_delegated_frozen_balance_for_bandwidth\x18) \x01(\x03\x12.\n&delegated_frozen_balance_for_bandwidth\x18* \x01(\x03\x12\x16\n\x0eold_tron_power\x18. \x01(\x03\x12,\n\ntron_power\x18/ \x01(\x0b\x32\x18.protocol.Account.Frozen\x12\x17\n\x0f\x61sset_optimized\x18< \x01(\x08\x12\x13\n\x0b\x63reate_time\x18\t \x01(\x03\x12\x1c\n\x14latest_opration_time\x18\n \x01(\x03\x12\x11\n\tallowance\x18\x0b \x01(\x03\x12\x1c\n\x14latest_withdraw_time\x18\x0c \x01(\x03\x12\x0c\n\x04\x63ode\x18\r \x01(\x0c\x12\x12\n\nis_witness\x18\x0e \x01(\x08\x12\x14\n\x0cis_committee\x18\x0f \x01(\x08\x12/\n\rfrozen_supply\x18\x10 \x03(\x0b\x32\x18.protocol.Account.Frozen\x12\x19\n\x11\x61sset_issued_name\x18\x11 \x01(\x0c\x12\x17\n\x0f\x61sset_issued_ID\x18\x39 \x01(\x0c\x12T\n\x1blatest_asset_operation_time\x18\x12 \x03(\x0b\x32/.protocol.Account.LatestAssetOperationTimeEntry\x12X\n\x1dlatest_asset_operation_timeV2\x18: \x03(\x0b\x32\x31.protocol.Account.LatestAssetOperationTimeV2Entry\x12\x16\n\x0e\x66ree_net_usage\x18\x13 \x01(\x03\x12\x46\n\x14\x66ree_asset_net_usage\x18\x14 \x03(\x0b\x32(.protocol.Account.FreeAssetNetUsageEntry\x12J\n\x16\x66ree_asset_net_usageV2\x18; \x03(\x0b\x32*.protocol.Account.FreeAssetNetUsageV2Entry\x12\x1b\n\x13latest_consume_time\x18\x15 \x01(\x03\x12 \n\x18latest_consume_free_time\x18\x16 \x01(\x03\x12\x12\n\naccount_id\x18\x17 \x01(\x0c\x12\x17\n\x0fnet_window_size\x18\x18 \x01(\x03\x12\x1c\n\x14net_window_optimized\x18\x19 \x01(\x08\x12;\n\x10\x61\x63\x63ount_resource\x18\x1a \x01(\x0b\x32!.protocol.Account.AccountResource\x12\x10\n\x08\x63odeHash\x18\x1e \x01(\x0c\x12.\n\x10owner_permission\x18\x1f \x01(\x0b\x32\x14.protocol.Permission\x12\x30\n\x12witness_permission\x18  \x01(\x0b\x32\x14.protocol.Permission\x12/\n\x11\x61\x63tive_permission\x18! \x03(\x0b\x32\x14.protocol.Permission\x12,\n\x08\x66rozenV2\x18\" \x03(\x0b\x32\x1a.protocol.Account.FreezeV2\x12\x30\n\nunfrozenV2\x18# \x03(\x0b\x32\x1c.protocol.Account.UnFreezeV2\x12\x30\n(delegated_frozenV2_balance_for_bandwidth\x18$ \x01(\x03\x12\x39\n1acquired_delegated_frozenV2_balance_for_bandwidth\x18% \x01(\x03\x1a\x35\n\x06\x46rozen\x12\x16\n\x0e\x66rozen_balance\x18\x01 \x01(\x03\x12\x13\n\x0b\x65xpire_time\x18\x02 \x01(\x03\x1a,\n\nAssetEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a.\n\x0c\x41ssetV2Entry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a?\n\x1dLatestAssetOperationTimeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x41\n\x1fLatestAssetOperationTimeV2Entry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x38\n\x16\x46reeAssetNetUsageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a:\n\x18\x46reeAssetNetUsageV2Entry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\xe7\x03\n\x0f\x41\x63\x63ountResource\x12\x14\n\x0c\x65nergy_usage\x18\x01 \x01(\x03\x12;\n\x19\x66rozen_balance_for_energy\x18\x02 \x01(\x0b\x32\x18.protocol.Account.Frozen\x12&\n\x1elatest_consume_time_for_energy\x18\x03 \x01(\x03\x12\x34\n,acquired_delegated_frozen_balance_for_energy\x18\x04 \x01(\x03\x12+\n#delegated_frozen_balance_for_energy\x18\x05 \x01(\x03\x12\x15\n\rstorage_limit\x18\x06 \x01(\x03\x12\x15\n\rstorage_usage\x18\x07 \x01(\x03\x12$\n\x1clatest_exchange_storage_time\x18\x08 \x01(\x03\x12\x1a\n\x12\x65nergy_window_size\x18\t \x01(\x03\x12-\n%delegated_frozenV2_balance_for_energy\x18\n \x01(\x03\x12\x36\n.acquired_delegated_frozenV2_balance_for_energy\x18\x0b \x01(\x03\x12\x1f\n\x17\x65nergy_window_optimized\x18\x0c \x01(\x08\x1a@\n\x08\x46reezeV2\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.protocol.ResourceCode\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x03\x1ai\n\nUnFreezeV2\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.protocol.ResourceCode\x12\x17\n\x0funfreeze_amount\x18\x03 \x01(\x03\x12\x1c\n\x14unfreeze_expire_time\x18\x04 \x01(\x03\"&\n\x03Key\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x0e\n\x06weight\x18\x02 \x01(\x03\"\xb9\x01\n\x11\x44\x65legatedResource\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x0c\x12\n\n\x02to\x18\x02 \x01(\x0c\x12$\n\x1c\x66rozen_balance_for_bandwidth\x18\x03 \x01(\x03\x12!\n\x19\x66rozen_balance_for_energy\x18\x04 \x01(\x03\x12!\n\x19\x65xpire_time_for_bandwidth\x18\x05 \x01(\x03\x12\x1e\n\x16\x65xpire_time_for_energy\x18\x06 \x01(\x03\"J\n\tauthority\x12$\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x13.protocol.AccountId\x12\x17\n\x0fpermission_name\x18\x02 \x01(\x0c\"\xf1\x01\n\nPermission\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.protocol.Permission.PermissionType\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x17\n\x0fpermission_name\x18\x03 \x01(\t\x12\x11\n\tthreshold\x18\x04 \x01(\x03\x12\x11\n\tparent_id\x18\x05 \x01(\x05\x12\x12\n\noperations\x18\x06 \x01(\x0c\x12\x1b\n\x04keys\x18\x07 \x03(\x0b\x32\r.protocol.Key\"4\n\x0ePermissionType\x12\t\n\x05Owner\x10\x00\x12\x0b\n\x07Witness\x10\x01\x12\n\n\x06\x41\x63tive\x10\x02\"\xb5\x01\n\x07Witness\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x11\n\tvoteCount\x18\x02 \x01(\x03\x12\x0e\n\x06pubKey\x18\x03 \x01(\x0c\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x15\n\rtotalProduced\x18\x05 \x01(\x03\x12\x13\n\x0btotalMissed\x18\x06 \x01(\x03\x12\x16\n\x0elatestBlockNum\x18\x07 \x01(\x03\x12\x15\n\rlatestSlotNum\x18\x08 \x01(\x03\x12\x0e\n\x06isJobs\x18\t \x01(\x08\"^\n\x05Votes\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12!\n\told_votes\x18\x02 \x03(\x0b\x32\x0e.protocol.Vote\x12!\n\tnew_votes\x18\x03 \x03(\x0b\x32\x0e.protocol.Vote\"-\n\x08TXOutput\x12\r\n\x05value\x18\x01 \x01(\x03\x12\x12\n\npubKeyHash\x18\x02 \x01(\x0c\"x\n\x07TXInput\x12\'\n\x08raw_data\x18\x01 \x01(\x0b\x32\x15.protocol.TXInput.raw\x12\x11\n\tsignature\x18\x04 \x01(\x0c\x1a\x31\n\x03raw\x12\x0c\n\x04txID\x18\x01 \x01(\x0c\x12\x0c\n\x04vout\x18\x02 \x01(\x03\x12\x0e\n\x06pubKey\x18\x03 \x01(\x0c\"0\n\tTXOutputs\x12#\n\x07outputs\x18\x01 \x03(\x0b\x32\x12.protocol.TXOutput\"\xf3\x01\n\x0fResourceReceipt\x12\x14\n\x0c\x65nergy_usage\x18\x01 \x01(\x03\x12\x12\n\nenergy_fee\x18\x02 \x01(\x03\x12\x1b\n\x13origin_energy_usage\x18\x03 \x01(\x03\x12\x1a\n\x12\x65nergy_usage_total\x18\x04 \x01(\x03\x12\x11\n\tnet_usage\x18\x05 \x01(\x03\x12\x0f\n\x07net_fee\x18\x06 \x01(\x03\x12;\n\x06result\x18\x07 \x01(\x0e\x32+.protocol.Transaction.Result.contractResult\x12\x1c\n\x14\x65nergy_penalty_total\x18\x08 \x01(\x03\"r\n\x11MarketOrderDetail\x12\x14\n\x0cmakerOrderId\x18\x01 \x01(\x0c\x12\x14\n\x0ctakerOrderId\x18\x02 \x01(\x0c\x12\x18\n\x10\x66illSellQuantity\x18\x03 \x01(\x03\x12\x17\n\x0f\x66illBuyQuantity\x18\x04 \x01(\x03\"\x94\x15\n\x0bTransaction\x12+\n\x08raw_data\x18\x01 \x01(\x0b\x32\x19.protocol.Transaction.raw\x12\x11\n\tsignature\x18\x02 \x03(\x0c\x12)\n\x03ret\x18\x05 \x03(\x0b\x32\x1c.protocol.Transaction.Result\x1a\xb8\n\n\x08\x43ontract\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.protocol.Transaction.Contract.ContractType\x12\'\n\tparameter\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x10\n\x08provider\x18\x03 \x01(\x0c\x12\x14\n\x0c\x43ontractName\x18\x04 \x01(\x0c\x12\x15\n\rPermission_id\x18\x05 \x01(\x05\"\x88\t\n\x0c\x43ontractType\x12\x19\n\x15\x41\x63\x63ountCreateContract\x10\x00\x12\x14\n\x10TransferContract\x10\x01\x12\x19\n\x15TransferAssetContract\x10\x02\x12\x15\n\x11VoteAssetContract\x10\x03\x12\x17\n\x13VoteWitnessContract\x10\x04\x12\x19\n\x15WitnessCreateContract\x10\x05\x12\x16\n\x12\x41ssetIssueContract\x10\x06\x12\x19\n\x15WitnessUpdateContract\x10\x08\x12!\n\x1dParticipateAssetIssueContract\x10\t\x12\x19\n\x15\x41\x63\x63ountUpdateContract\x10\n\x12\x19\n\x15\x46reezeBalanceContract\x10\x0b\x12\x1b\n\x17UnfreezeBalanceContract\x10\x0c\x12\x1b\n\x17WithdrawBalanceContract\x10\r\x12\x19\n\x15UnfreezeAssetContract\x10\x0e\x12\x17\n\x13UpdateAssetContract\x10\x0f\x12\x1a\n\x16ProposalCreateContract\x10\x10\x12\x1b\n\x17ProposalApproveContract\x10\x11\x12\x1a\n\x16ProposalDeleteContract\x10\x12\x12\x18\n\x14SetAccountIdContract\x10\x13\x12\x12\n\x0e\x43ustomContract\x10\x14\x12\x17\n\x13\x43reateSmartContract\x10\x1e\x12\x18\n\x14TriggerSmartContract\x10\x1f\x12\x0f\n\x0bGetContract\x10 \x12\x19\n\x15UpdateSettingContract\x10!\x12\x1a\n\x16\x45xchangeCreateContract\x10)\x12\x1a\n\x16\x45xchangeInjectContract\x10*\x12\x1c\n\x18\x45xchangeWithdrawContract\x10+\x12\x1f\n\x1b\x45xchangeTransactionContract\x10,\x12\x1d\n\x19UpdateEnergyLimitContract\x10-\x12#\n\x1f\x41\x63\x63ountPermissionUpdateContract\x10.\x12\x14\n\x10\x43learABIContract\x10\x30\x12\x1b\n\x17UpdateBrokerageContract\x10\x31\x12\x1c\n\x18ShieldedTransferContract\x10\x33\x12\x1b\n\x17MarketSellAssetContract\x10\x34\x12\x1d\n\x19MarketCancelOrderContract\x10\x35\x12\x1b\n\x17\x46reezeBalanceV2Contract\x10\x36\x12\x1d\n\x19UnfreezeBalanceV2Contract\x10\x37\x12\"\n\x1eWithdrawExpireUnfreezeContract\x10\x38\x12\x1c\n\x18\x44\x65legateResourceContract\x10\x39\x12\x1e\n\x1aUnDelegateResourceContract\x10:\x12\x1f\n\x1b\x43\x61ncelAllUnfreezeV2Contract\x10;\x1a\xdf\x07\n\x06Result\x12\x0b\n\x03\x66\x65\x65\x18\x01 \x01(\x03\x12.\n\x03ret\x18\x02 \x01(\x0e\x32!.protocol.Transaction.Result.code\x12@\n\x0b\x63ontractRet\x18\x03 \x01(\x0e\x32+.protocol.Transaction.Result.contractResult\x12\x14\n\x0c\x61ssetIssueID\x18\x0e \x01(\t\x12\x17\n\x0fwithdraw_amount\x18\x0f \x01(\x03\x12\x17\n\x0funfreeze_amount\x18\x10 \x01(\x03\x12 \n\x18\x65xchange_received_amount\x18\x12 \x01(\x03\x12&\n\x1e\x65xchange_inject_another_amount\x18\x13 \x01(\x03\x12(\n exchange_withdraw_another_amount\x18\x14 \x01(\x03\x12\x13\n\x0b\x65xchange_id\x18\x15 \x01(\x03\x12 \n\x18shielded_transaction_fee\x18\x16 \x01(\x03\x12\x0f\n\x07orderId\x18\x19 \x01(\x0c\x12\x31\n\x0corderDetails\x18\x1a \x03(\x0b\x32\x1b.protocol.MarketOrderDetail\x12\x1e\n\x16withdraw_expire_amount\x18\x1b \x01(\x03\x12Z\n\x18\x63\x61ncel_unfreezeV2_amount\x18\x1c \x03(\x0b\x32\x38.protocol.Transaction.Result.CancelUnfreezeV2AmountEntry\x1a=\n\x1b\x43\x61ncelUnfreezeV2AmountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\x1e\n\x04\x63ode\x12\n\n\x06SUCESS\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\"\xc3\x02\n\x0e\x63ontractResult\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\n\n\x06REVERT\x10\x02\x12\x18\n\x14\x42\x41\x44_JUMP_DESTINATION\x10\x03\x12\x11\n\rOUT_OF_MEMORY\x10\x04\x12\x18\n\x14PRECOMPILED_CONTRACT\x10\x05\x12\x13\n\x0fSTACK_TOO_SMALL\x10\x06\x12\x13\n\x0fSTACK_TOO_LARGE\x10\x07\x12\x15\n\x11ILLEGAL_OPERATION\x10\x08\x12\x12\n\x0eSTACK_OVERFLOW\x10\t\x12\x11\n\rOUT_OF_ENERGY\x10\n\x12\x0f\n\x0bOUT_OF_TIME\x10\x0b\x12\x17\n\x13JVM_STACK_OVER_FLOW\x10\x0c\x12\x0b\n\x07UNKNOWN\x10\r\x12\x13\n\x0fTRANSFER_FAILED\x10\x0e\x12\x10\n\x0cINVALID_CODE\x10\x0f\x1a\xfc\x01\n\x03raw\x12\x17\n\x0fref_block_bytes\x18\x01 \x01(\x0c\x12\x15\n\rref_block_num\x18\x03 \x01(\x03\x12\x16\n\x0eref_block_hash\x18\x04 \x01(\x0c\x12\x12\n\nexpiration\x18\x08 \x01(\x03\x12\"\n\x05\x61uths\x18\t \x03(\x0b\x32\x13.protocol.authority\x12\x0c\n\x04\x64\x61ta\x18\n \x01(\x0c\x12\x30\n\x08\x63ontract\x18\x0b \x03(\x0b\x32\x1e.protocol.Transaction.Contract\x12\x0f\n\x07scripts\x18\x0c \x01(\x0c\x12\x11\n\ttimestamp\x18\x0e \x01(\x03\x12\x11\n\tfee_limit\x18\x12 \x01(\x03\"\xbc\x07\n\x0fTransactionInfo\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\x0b\n\x03\x66\x65\x65\x18\x02 \x01(\x03\x12\x13\n\x0b\x62lockNumber\x18\x03 \x01(\x03\x12\x16\n\x0e\x62lockTimeStamp\x18\x04 \x01(\x03\x12\x16\n\x0e\x63ontractResult\x18\x05 \x03(\x0c\x12\x18\n\x10\x63ontract_address\x18\x06 \x01(\x0c\x12*\n\x07receipt\x18\x07 \x01(\x0b\x32\x19.protocol.ResourceReceipt\x12*\n\x03log\x18\x08 \x03(\x0b\x32\x1d.protocol.TransactionInfo.Log\x12.\n\x06result\x18\t \x01(\x0e\x32\x1e.protocol.TransactionInfo.code\x12\x12\n\nresMessage\x18\n \x01(\x0c\x12\x14\n\x0c\x61ssetIssueID\x18\x0e \x01(\t\x12\x17\n\x0fwithdraw_amount\x18\x0f \x01(\x03\x12\x17\n\x0funfreeze_amount\x18\x10 \x01(\x03\x12<\n\x15internal_transactions\x18\x11 \x03(\x0b\x32\x1d.protocol.InternalTransaction\x12 \n\x18\x65xchange_received_amount\x18\x12 \x01(\x03\x12&\n\x1e\x65xchange_inject_another_amount\x18\x13 \x01(\x03\x12(\n exchange_withdraw_another_amount\x18\x14 \x01(\x03\x12\x13\n\x0b\x65xchange_id\x18\x15 \x01(\x03\x12 \n\x18shielded_transaction_fee\x18\x16 \x01(\x03\x12\x0f\n\x07orderId\x18\x19 \x01(\x0c\x12\x31\n\x0corderDetails\x18\x1a \x03(\x0b\x32\x1b.protocol.MarketOrderDetail\x12\x12\n\npackingFee\x18\x1b \x01(\x03\x12\x1e\n\x16withdraw_expire_amount\x18\x1c \x01(\x03\x12W\n\x18\x63\x61ncel_unfreezeV2_amount\x18\x1d \x03(\x0b\x32\x35.protocol.TransactionInfo.CancelUnfreezeV2AmountEntry\x1a\x34\n\x03Log\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x0e\n\x06topics\x18\x02 \x03(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x1a=\n\x1b\x43\x61ncelUnfreezeV2AmountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\x1e\n\x04\x63ode\x12\n\n\x06SUCESS\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\"q\n\x0eTransactionRet\x12\x13\n\x0b\x62lockNumber\x18\x01 \x01(\x03\x12\x16\n\x0e\x62lockTimeStamp\x18\x02 \x01(\x03\x12\x32\n\x0ftransactioninfo\x18\x03 \x03(\x0b\x32\x19.protocol.TransactionInfo\";\n\x0cTransactions\x12+\n\x0ctransactions\x18\x01 \x03(\x0b\x32\x15.protocol.Transaction\"\x80\x02\n\x0b\x42lockHeader\x12+\n\x08raw_data\x18\x01 \x01(\x0b\x32\x19.protocol.BlockHeader.raw\x12\x19\n\x11witness_signature\x18\x02 \x01(\x0c\x1a\xa8\x01\n\x03raw\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x12\n\ntxTrieRoot\x18\x02 \x01(\x0c\x12\x12\n\nparentHash\x18\x03 \x01(\x0c\x12\x0e\n\x06number\x18\x07 \x01(\x03\x12\x12\n\nwitness_id\x18\x08 \x01(\x03\x12\x17\n\x0fwitness_address\x18\t \x01(\x0c\x12\x0f\n\x07version\x18\n \x01(\x05\x12\x18\n\x10\x61\x63\x63ountStateRoot\x18\x0b \x01(\x0c\"a\n\x05\x42lock\x12+\n\x0ctransactions\x18\x01 \x03(\x0b\x32\x15.protocol.Transaction\x12+\n\x0c\x62lock_header\x18\x02 \x01(\x0b\x32\x15.protocol.BlockHeader\"|\n\x0e\x43hainInventory\x12-\n\x03ids\x18\x01 \x03(\x0b\x32 .protocol.ChainInventory.BlockId\x12\x12\n\nremain_num\x18\x02 \x01(\x03\x1a\'\n\x07\x42lockId\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0e\n\x06number\x18\x02 \x01(\x03\"\xbf\x01\n\x0e\x42lockInventory\x12-\n\x03ids\x18\x01 \x03(\x0b\x32 .protocol.BlockInventory.BlockId\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x1d.protocol.BlockInventory.Type\x1a\'\n\x07\x42lockId\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0e\n\x06number\x18\x02 \x01(\x03\"(\n\x04Type\x12\x08\n\x04SYNC\x10\x00\x12\x0b\n\x07\x41\x44VTISE\x10\x01\x12\t\n\x05\x46\x45TCH\x10\x02\"n\n\tInventory\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.protocol.Inventory.InventoryType\x12\x0b\n\x03ids\x18\x02 \x03(\x0c\"#\n\rInventoryType\x12\x07\n\x03TRX\x10\x00\x12\t\n\x05\x42LOCK\x10\x01\"\xe5\x01\n\x05Items\x12&\n\x04type\x18\x01 \x01(\x0e\x32\x18.protocol.Items.ItemType\x12\x1f\n\x06\x62locks\x18\x02 \x03(\x0b\x32\x0f.protocol.Block\x12,\n\rblock_headers\x18\x03 \x03(\x0b\x32\x15.protocol.BlockHeader\x12+\n\x0ctransactions\x18\x04 \x03(\x0b\x32\x15.protocol.Transaction\"8\n\x08ItemType\x12\x07\n\x03\x45RR\x10\x00\x12\x07\n\x03TRX\x10\x01\x12\t\n\x05\x42LOCK\x10\x02\x12\x0f\n\x0b\x42LOCKHEADER\x10\x03\"4\n\x11\x44ynamicProperties\x12\x1f\n\x17last_solidity_block_num\x18\x01 \x01(\x03\"9\n\x11\x44isconnectMessage\x12$\n\x06reason\x18\x01 \x01(\x0e\x32\x14.protocol.ReasonCode\"\x83\x03\n\x0cHelloMessage\x12 \n\x04\x66rom\x18\x01 \x01(\x0b\x32\x12.protocol.Endpoint\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x36\n\x0egenesisBlockId\x18\x04 \x01(\x0b\x32\x1e.protocol.HelloMessage.BlockId\x12\x34\n\x0csolidBlockId\x18\x05 \x01(\x0b\x32\x1e.protocol.HelloMessage.BlockId\x12\x33\n\x0bheadBlockId\x18\x06 \x01(\x0b\x32\x1e.protocol.HelloMessage.BlockId\x12\x0f\n\x07\x61\x64\x64ress\x18\x07 \x01(\x0c\x12\x11\n\tsignature\x18\x08 \x01(\x0c\x12\x10\n\x08nodeType\x18\t \x01(\x05\x12\x16\n\x0elowestBlockNum\x18\n \x01(\x03\x12\x13\n\x0b\x63odeVersion\x18\x0b \x01(\x0c\x1a\'\n\x07\x42lockId\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0e\n\x06number\x18\x02 \x01(\x03\"\xff\x01\n\x13InternalTransaction\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x16\n\x0e\x63\x61ller_address\x18\x02 \x01(\x0c\x12\x1a\n\x12transferTo_address\x18\x03 \x01(\x0c\x12\x42\n\rcallValueInfo\x18\x04 \x03(\x0b\x32+.protocol.InternalTransaction.CallValueInfo\x12\x0c\n\x04note\x18\x05 \x01(\x0c\x12\x10\n\x08rejected\x18\x06 \x01(\x08\x12\r\n\x05\x65xtra\x18\x07 \x01(\t\x1a\x33\n\rCallValueInfo\x12\x11\n\tcallValue\x18\x01 \x01(\x03\x12\x0f\n\x07tokenId\x18\x02 \x01(\t\"m\n\x1d\x44\x65legatedResourceAccountIndex\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0c\x12\x14\n\x0c\x66romAccounts\x18\x02 \x03(\x0c\x12\x12\n\ntoAccounts\x18\x03 \x03(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\"\x9f\x11\n\x08NodeInfo\x12\x14\n\x0c\x62\x65ginSyncNum\x18\x01 \x01(\x03\x12\r\n\x05\x62lock\x18\x02 \x01(\t\x12\x15\n\rsolidityBlock\x18\x03 \x01(\t\x12\x1b\n\x13\x63urrentConnectCount\x18\x04 \x01(\x05\x12\x1a\n\x12\x61\x63tiveConnectCount\x18\x05 \x01(\x05\x12\x1b\n\x13passiveConnectCount\x18\x06 \x01(\x05\x12\x11\n\ttotalFlow\x18\x07 \x01(\x03\x12\x31\n\x0cpeerInfoList\x18\x08 \x03(\x0b\x32\x1b.protocol.NodeInfo.PeerInfo\x12\x39\n\x0e\x63onfigNodeInfo\x18\t \x01(\x0b\x32!.protocol.NodeInfo.ConfigNodeInfo\x12\x33\n\x0bmachineInfo\x18\n \x01(\x0b\x32\x1e.protocol.NodeInfo.MachineInfo\x12H\n\x13\x63heatWitnessInfoMap\x18\x0b \x03(\x0b\x32+.protocol.NodeInfo.CheatWitnessInfoMapEntry\x1a:\n\x18\x43heatWitnessInfoMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xcd\x04\n\x08PeerInfo\x12\x15\n\rlastSyncBlock\x18\x01 \x01(\t\x12\x11\n\tremainNum\x18\x02 \x01(\x03\x12\x1b\n\x13lastBlockUpdateTime\x18\x03 \x01(\x03\x12\x10\n\x08syncFlag\x18\x04 \x01(\x08\x12\x1f\n\x17headBlockTimeWeBothHave\x18\x05 \x01(\x03\x12\x18\n\x10needSyncFromPeer\x18\x06 \x01(\x08\x12\x16\n\x0eneedSyncFromUs\x18\x07 \x01(\x08\x12\x0c\n\x04host\x18\x08 \x01(\t\x12\x0c\n\x04port\x18\t \x01(\x05\x12\x0e\n\x06nodeId\x18\n \x01(\t\x12\x13\n\x0b\x63onnectTime\x18\x0b \x01(\x03\x12\x12\n\navgLatency\x18\x0c \x01(\x01\x12\x17\n\x0fsyncToFetchSize\x18\r \x01(\x05\x12\x1e\n\x16syncToFetchSizePeekNum\x18\x0e \x01(\x03\x12\x1e\n\x16syncBlockRequestedSize\x18\x0f \x01(\x05\x12\x15\n\runFetchSynNum\x18\x10 \x01(\x03\x12\x17\n\x0f\x62lockInPorcSize\x18\x11 \x01(\x05\x12\x1b\n\x13headBlockWeBothHave\x18\x12 \x01(\t\x12\x10\n\x08isActive\x18\x13 \x01(\x08\x12\r\n\x05score\x18\x14 \x01(\x05\x12\x11\n\tnodeCount\x18\x15 \x01(\x05\x12\x0e\n\x06inFlow\x18\x16 \x01(\x03\x12\x17\n\x0f\x64isconnectTimes\x18\x17 \x01(\x05\x12\x1d\n\x15localDisconnectReason\x18\x18 \x01(\t\x12\x1e\n\x16remoteDisconnectReason\x18\x19 \x01(\t\x1a\xe5\x03\n\x0e\x43onfigNodeInfo\x12\x13\n\x0b\x63odeVersion\x18\x01 \x01(\t\x12\x12\n\np2pVersion\x18\x02 \x01(\t\x12\x12\n\nlistenPort\x18\x03 \x01(\x05\x12\x16\n\x0e\x64iscoverEnable\x18\x04 \x01(\x08\x12\x16\n\x0e\x61\x63tiveNodeSize\x18\x05 \x01(\x05\x12\x17\n\x0fpassiveNodeSize\x18\x06 \x01(\x05\x12\x14\n\x0csendNodeSize\x18\x07 \x01(\x05\x12\x17\n\x0fmaxConnectCount\x18\x08 \x01(\x05\x12\x1d\n\x15sameIpMaxConnectCount\x18\t \x01(\x05\x12\x18\n\x10\x62\x61\x63kupListenPort\x18\n \x01(\x05\x12\x18\n\x10\x62\x61\x63kupMemberSize\x18\x0b \x01(\x05\x12\x16\n\x0e\x62\x61\x63kupPriority\x18\x0c \x01(\x05\x12\x11\n\tdbVersion\x18\r \x01(\x05\x12\x1c\n\x14minParticipationRate\x18\x0e \x01(\x05\x12\x17\n\x0fsupportConstant\x18\x0f \x01(\x08\x12\x14\n\x0cminTimeRatio\x18\x10 \x01(\x01\x12\x14\n\x0cmaxTimeRatio\x18\x11 \x01(\x01\x12 \n\x18\x61llowCreationOfContracts\x18\x12 \x01(\x03\x12\x1b\n\x13\x61llowAdaptiveEnergy\x18\x13 \x01(\x03\x1a\x8c\x05\n\x0bMachineInfo\x12\x13\n\x0bthreadCount\x18\x01 \x01(\x05\x12\x1b\n\x13\x64\x65\x61\x64LockThreadCount\x18\x02 \x01(\x05\x12\x10\n\x08\x63puCount\x18\x03 \x01(\x05\x12\x13\n\x0btotalMemory\x18\x04 \x01(\x03\x12\x12\n\nfreeMemory\x18\x05 \x01(\x03\x12\x0f\n\x07\x63puRate\x18\x06 \x01(\x01\x12\x13\n\x0bjavaVersion\x18\x07 \x01(\t\x12\x0e\n\x06osName\x18\x08 \x01(\t\x12\x16\n\x0ejvmTotalMemory\x18\t \x01(\x03\x12\x15\n\rjvmFreeMemory\x18\n \x01(\x03\x12\x16\n\x0eprocessCpuRate\x18\x0b \x01(\x01\x12I\n\x12memoryDescInfoList\x18\x0c \x03(\x0b\x32-.protocol.NodeInfo.MachineInfo.MemoryDescInfo\x12Q\n\x16\x64\x65\x61\x64LockThreadInfoList\x18\r \x03(\x0b\x32\x31.protocol.NodeInfo.MachineInfo.DeadLockThreadInfo\x1a\x63\n\x0eMemoryDescInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08initSize\x18\x02 \x01(\x03\x12\x0f\n\x07useSize\x18\x03 \x01(\x03\x12\x0f\n\x07maxSize\x18\x04 \x01(\x03\x12\x0f\n\x07useRate\x18\x05 \x01(\x01\x1a\x8f\x01\n\x12\x44\x65\x61\x64LockThreadInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08lockName\x18\x02 \x01(\t\x12\x11\n\tlockOwner\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x11\n\tblockTime\x18\x05 \x01(\x03\x12\x10\n\x08waitTime\x18\x06 \x01(\x03\x12\x12\n\nstackTrace\x18\x07 \x01(\t\"\xbd\x12\n\x0bMetricsInfo\x12\x10\n\x08interval\x18\x01 \x01(\x03\x12,\n\x04node\x18\x02 \x01(\x0b\x32\x1e.protocol.MetricsInfo.NodeInfo\x12\x38\n\nblockchain\x18\x03 \x01(\x0b\x32$.protocol.MetricsInfo.BlockChainInfo\x12*\n\x03net\x18\x04 \x01(\x0b\x32\x1d.protocol.MetricsInfo.NetInfo\x1aO\n\x08NodeInfo\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x10\n\x08nodeType\x18\x02 \x01(\x05\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x14\n\x0c\x62\x61\x63kupStatus\x18\x04 \x01(\x05\x1a\xf3\x04\n\x0e\x42lockChainInfo\x12\x14\n\x0cheadBlockNum\x18\x01 \x01(\x03\x12\x1a\n\x12headBlockTimestamp\x18\x02 \x01(\x03\x12\x15\n\rheadBlockHash\x18\x03 \x01(\t\x12\x11\n\tforkCount\x18\x04 \x01(\x05\x12\x15\n\rfailForkCount\x18\x05 \x01(\x05\x12\x38\n\x10\x62lockProcessTime\x18\x06 \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x12+\n\x03tps\x18\x07 \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x12\x1c\n\x14transactionCacheSize\x18\x08 \x01(\x05\x12\x39\n\x11missedTransaction\x18\t \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x12?\n\twitnesses\x18\n \x03(\x0b\x32,.protocol.MetricsInfo.BlockChainInfo.Witness\x12\x1b\n\x13\x66\x61ilProcessBlockNum\x18\x0b \x01(\x03\x12\x1e\n\x16\x66\x61ilProcessBlockReason\x18\x0c \x01(\t\x12\x43\n\ndupWitness\x18\r \x03(\x0b\x32/.protocol.MetricsInfo.BlockChainInfo.DupWitness\x1a+\n\x07Witness\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x1a>\n\nDupWitness\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x10\n\x08\x62lockNum\x18\x02 \x01(\x03\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x1au\n\x08RateInfo\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x10\n\x08meanRate\x18\x02 \x01(\x01\x12\x15\n\roneMinuteRate\x18\x03 \x01(\x01\x12\x16\n\x0e\x66iveMinuteRate\x18\x04 \x01(\x01\x12\x19\n\x11\x66ifteenMinuteRate\x18\x05 \x01(\x01\x1a\xc9\n\n\x07NetInfo\x12\x17\n\x0f\x65rrorProtoCount\x18\x01 \x01(\x05\x12\x32\n\x03\x61pi\x18\x02 \x01(\x0b\x32%.protocol.MetricsInfo.NetInfo.ApiInfo\x12\x17\n\x0f\x63onnectionCount\x18\x03 \x01(\x05\x12\x1c\n\x14validConnectionCount\x18\x04 \x01(\x05\x12\x34\n\x0ctcpInTraffic\x18\x05 \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x12\x35\n\rtcpOutTraffic\x18\x06 \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x12\x1a\n\x12\x64isconnectionCount\x18\x07 \x01(\x05\x12R\n\x13\x64isconnectionDetail\x18\x08 \x03(\x0b\x32\x35.protocol.MetricsInfo.NetInfo.DisconnectionDetailInfo\x12\x34\n\x0cudpInTraffic\x18\t \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x12\x35\n\rudpOutTraffic\x18\n \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x12:\n\x07latency\x18\x0b \x01(\x0b\x32).protocol.MetricsInfo.NetInfo.LatencyInfo\x1a\x92\x03\n\x07\x41piInfo\x12+\n\x03qps\x18\x01 \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x12/\n\x07\x66\x61ilQps\x18\x02 \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x12\x32\n\noutTraffic\x18\x03 \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x12\x43\n\x06\x64\x65tail\x18\x04 \x03(\x0b\x32\x33.protocol.MetricsInfo.NetInfo.ApiInfo.ApiDetailInfo\x1a\xaf\x01\n\rApiDetailInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x03qps\x18\x02 \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x12/\n\x07\x66\x61ilQps\x18\x03 \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x12\x32\n\noutTraffic\x18\x04 \x01(\x0b\x32\x1e.protocol.MetricsInfo.RateInfo\x1a\x38\n\x17\x44isconnectionDetailInfo\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x1a\xe4\x02\n\x0bLatencyInfo\x12\r\n\x05top99\x18\x01 \x01(\x05\x12\r\n\x05top95\x18\x02 \x01(\x05\x12\r\n\x05top75\x18\x03 \x01(\x05\x12\x12\n\ntotalCount\x18\x04 \x01(\x05\x12\x0f\n\x07\x64\x65lay1S\x18\x05 \x01(\x05\x12\x0f\n\x07\x64\x65lay2S\x18\x06 \x01(\x05\x12\x0f\n\x07\x64\x65lay3S\x18\x07 \x01(\x05\x12K\n\x06\x64\x65tail\x18\x08 \x03(\x0b\x32;.protocol.MetricsInfo.NetInfo.LatencyInfo.LatencyDetailInfo\x1a\x93\x01\n\x11LatencyDetailInfo\x12\x0f\n\x07witness\x18\x01 \x01(\t\x12\r\n\x05top99\x18\x02 \x01(\x05\x12\r\n\x05top95\x18\x03 \x01(\x05\x12\r\n\x05top75\x18\x04 \x01(\x05\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\x12\x0f\n\x07\x64\x65lay1S\x18\x06 \x01(\x05\x12\x0f\n\x07\x64\x65lay2S\x18\x07 \x01(\x05\x12\x0f\n\x07\x64\x65lay3S\x18\x08 \x01(\x05\"\xd8\x02\n\x0bPBFTMessage\x12+\n\x08raw_data\x18\x01 \x01(\x0b\x32\x19.protocol.PBFTMessage.Raw\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x1a\x96\x01\n\x03Raw\x12/\n\x08msg_type\x18\x01 \x01(\x0e\x32\x1d.protocol.PBFTMessage.MsgType\x12\x31\n\tdata_type\x18\x02 \x01(\x0e\x32\x1e.protocol.PBFTMessage.DataType\x12\x0e\n\x06view_n\x18\x03 \x01(\x03\x12\r\n\x05\x65poch\x18\x04 \x01(\x03\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\"P\n\x07MsgType\x12\x0f\n\x0bVIEW_CHANGE\x10\x00\x12\x0b\n\x07REQUEST\x10\x01\x12\x0e\n\nPREPREPARE\x10\x02\x12\x0b\n\x07PREPARE\x10\x03\x12\n\n\x06\x43OMMIT\x10\x04\"\x1e\n\x08\x44\x61taType\x12\t\n\x05\x42LOCK\x10\x00\x12\x07\n\x03SRL\x10\x01\"3\n\x10PBFTCommitResult\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x03(\x0c\"\x18\n\x03SRL\x12\x11\n\tsrAddress\x18\x01 \x03(\x0c*7\n\x0b\x41\x63\x63ountType\x12\n\n\x06Normal\x10\x00\x12\x0e\n\nAssetIssue\x10\x01\x12\x0c\n\x08\x43ontract\x10\x02*\x9f\x04\n\nReasonCode\x12\r\n\tREQUESTED\x10\x00\x12\x10\n\x0c\x42\x41\x44_PROTOCOL\x10\x02\x12\x12\n\x0eTOO_MANY_PEERS\x10\x04\x12\x12\n\x0e\x44UPLICATE_PEER\x10\x05\x12\x19\n\x15INCOMPATIBLE_PROTOCOL\x10\x06\x12\x16\n\x12RANDOM_ELIMINATION\x10\x07\x12\x10\n\x0cPEER_QUITING\x10\x08\x12\x17\n\x13UNEXPECTED_IDENTITY\x10\t\x12\x12\n\x0eLOCAL_IDENTITY\x10\n\x12\x10\n\x0cPING_TIMEOUT\x10\x0b\x12\x0f\n\x0bUSER_REASON\x10\x10\x12\t\n\x05RESET\x10\x11\x12\r\n\tSYNC_FAIL\x10\x12\x12\x0e\n\nFETCH_FAIL\x10\x13\x12\n\n\x06\x42\x41\x44_TX\x10\x14\x12\r\n\tBAD_BLOCK\x10\x15\x12\n\n\x06\x46ORKED\x10\x16\x12\x0e\n\nUNLINKABLE\x10\x17\x12\x18\n\x14INCOMPATIBLE_VERSION\x10\x18\x12\x16\n\x12INCOMPATIBLE_CHAIN\x10\x19\x12\x0c\n\x08TIME_OUT\x10 \x12\x10\n\x0c\x43ONNECT_FAIL\x10!\x12\x1f\n\x1bTOO_MANY_PEERS_WITH_SAME_IP\x10\"\x12\x18\n\x14LIGHT_NODE_SYNC_FAIL\x10#\x12\x11\n\rBELOW_THAN_ME\x10$\x12\x0f\n\x0bNOT_WITNESS\x10%\x12\x13\n\x0fNO_SUCH_MESSAGE\x10&\x12\x0c\n\x07UNKNOWN\x10\xff\x01\x42\x46\n\x0forg.tron.protosB\x08ProtocolZ)github.com/tronprotocol/grpc-gateway/coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron_sdk_py.proto.core.Tron_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017org.tron.protosB\010ProtocolZ)github.com/tronprotocol/grpc-gateway/core'
  _globals['_PROPOSAL_PARAMETERSENTRY']._loaded_options = None
  _globals['_PROPOSAL_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_ACCOUNT_ASSETENTRY']._loaded_options = None
  _globals['_ACCOUNT_ASSETENTRY']._serialized_options = b'8\001'
  _globals['_ACCOUNT_ASSETV2ENTRY']._loaded_options = None
  _globals['_ACCOUNT_ASSETV2ENTRY']._serialized_options = b'8\001'
  _globals['_ACCOUNT_LATESTASSETOPERATIONTIMEENTRY']._loaded_options = None
  _globals['_ACCOUNT_LATESTASSETOPERATIONTIMEENTRY']._serialized_options = b'8\001'
  _globals['_ACCOUNT_LATESTASSETOPERATIONTIMEV2ENTRY']._loaded_options = None
  _globals['_ACCOUNT_LATESTASSETOPERATIONTIMEV2ENTRY']._serialized_options = b'8\001'
  _globals['_ACCOUNT_FREEASSETNETUSAGEENTRY']._loaded_options = None
  _globals['_ACCOUNT_FREEASSETNETUSAGEENTRY']._serialized_options = b'8\001'
  _globals['_ACCOUNT_FREEASSETNETUSAGEV2ENTRY']._loaded_options = None
  _globals['_ACCOUNT_FREEASSETNETUSAGEV2ENTRY']._serialized_options = b'8\001'
  _globals['_TRANSACTION_RESULT_CANCELUNFREEZEV2AMOUNTENTRY']._loaded_options = None
  _globals['_TRANSACTION_RESULT_CANCELUNFREEZEV2AMOUNTENTRY']._serialized_options = b'8\001'
  _globals['_TRANSACTIONINFO_CANCELUNFREEZEV2AMOUNTENTRY']._loaded_options = None
  _globals['_TRANSACTIONINFO_CANCELUNFREEZEV2AMOUNTENTRY']._serialized_options = b'8\001'
  _globals['_NODEINFO_CHEATWITNESSINFOMAPENTRY']._loaded_options = None
  _globals['_NODEINFO_CHEATWITNESSINFOMAPENTRY']._serialized_options = b'8\001'
  _globals['_ACCOUNTTYPE']._serialized_start=16678
  _globals['_ACCOUNTTYPE']._serialized_end=16733
  _globals['_REASONCODE']._serialized_start=16736
  _globals['_REASONCODE']._serialized_end=17279
  _globals['_ACCOUNTID']._serialized_start=159
  _globals['_ACCOUNTID']._serialized_end=201
  _globals['_VOTE']._serialized_start=203
  _globals['_VOTE']._serialized_end=251
  _globals['_PROPOSAL']._serialized_start=254
  _globals['_PROPOSAL']._serialized_end=591
  _globals['_PROPOSAL_PARAMETERSENTRY']._serialized_start=475
  _globals['_PROPOSAL_PARAMETERSENTRY']._serialized_end=524
  _globals['_PROPOSAL_STATE']._serialized_start=526
  _globals['_PROPOSAL_STATE']._serialized_end=591
  _globals['_EXCHANGE']._serialized_start=594
  _globals['_EXCHANGE']._serialized_end=779
  _globals['_MARKETORDER']._serialized_start=782
  _globals['_MARKETORDER']._serialized_end=1152
  _globals['_MARKETORDER_STATE']._serialized_start=1105
  _globals['_MARKETORDER_STATE']._serialized_end=1152
  _globals['_MARKETORDERLIST']._serialized_start=1154
  _globals['_MARKETORDERLIST']._serialized_end=1210
  _globals['_MARKETORDERPAIRLIST']._serialized_start=1212
  _globals['_MARKETORDERPAIRLIST']._serialized_end=1279
  _globals['_MARKETORDERPAIR']._serialized_start=1281
  _globals['_MARKETORDERPAIR']._serialized_end=1343
  _globals['_MARKETACCOUNTORDER']._serialized_start=1345
  _globals['_MARKETACCOUNTORDER']._serialized_end=1440
  _globals['_MARKETPRICE']._serialized_start=1442
  _globals['_MARKETPRICE']._serialized_end=1512
  _globals['_MARKETPRICELIST']._serialized_start=1514
  _globals['_MARKETPRICELIST']._serialized_end=1615
  _globals['_MARKETORDERIDLIST']._serialized_start=1617
  _globals['_MARKETORDERIDLIST']._serialized_end=1664
  _globals['_CHAINPARAMETERS']._serialized_start=1667
  _globals['_CHAINPARAMETERS']._serialized_end=1796
  _globals['_CHAINPARAMETERS_CHAINPARAMETER']._serialized_start=1752
  _globals['_CHAINPARAMETERS_CHAINPARAMETER']._serialized_end=1796
  _globals['_ACCOUNT']._serialized_start=1799
  _globals['_ACCOUNT']._serialized_end=4523
  _globals['_ACCOUNT_FROZEN']._serialized_start=3463
  _globals['_ACCOUNT_FROZEN']._serialized_end=3516
  _globals['_ACCOUNT_ASSETENTRY']._serialized_start=3518
  _globals['_ACCOUNT_ASSETENTRY']._serialized_end=3562
  _globals['_ACCOUNT_ASSETV2ENTRY']._serialized_start=3564
  _globals['_ACCOUNT_ASSETV2ENTRY']._serialized_end=3610
  _globals['_ACCOUNT_LATESTASSETOPERATIONTIMEENTRY']._serialized_start=3612
  _globals['_ACCOUNT_LATESTASSETOPERATIONTIMEENTRY']._serialized_end=3675
  _globals['_ACCOUNT_LATESTASSETOPERATIONTIMEV2ENTRY']._serialized_start=3677
  _globals['_ACCOUNT_LATESTASSETOPERATIONTIMEV2ENTRY']._serialized_end=3742
  _globals['_ACCOUNT_FREEASSETNETUSAGEENTRY']._serialized_start=3744
  _globals['_ACCOUNT_FREEASSETNETUSAGEENTRY']._serialized_end=3800
  _globals['_ACCOUNT_FREEASSETNETUSAGEV2ENTRY']._serialized_start=3802
  _globals['_ACCOUNT_FREEASSETNETUSAGEV2ENTRY']._serialized_end=3860
  _globals['_ACCOUNT_ACCOUNTRESOURCE']._serialized_start=3863
  _globals['_ACCOUNT_ACCOUNTRESOURCE']._serialized_end=4350
  _globals['_ACCOUNT_FREEZEV2']._serialized_start=4352
  _globals['_ACCOUNT_FREEZEV2']._serialized_end=4416
  _globals['_ACCOUNT_UNFREEZEV2']._serialized_start=4418
  _globals['_ACCOUNT_UNFREEZEV2']._serialized_end=4523
  _globals['_KEY']._serialized_start=4525
  _globals['_KEY']._serialized_end=4563
  _globals['_DELEGATEDRESOURCE']._serialized_start=4566
  _globals['_DELEGATEDRESOURCE']._serialized_end=4751
  _globals['_AUTHORITY']._serialized_start=4753
  _globals['_AUTHORITY']._serialized_end=4827
  _globals['_PERMISSION']._serialized_start=4830
  _globals['_PERMISSION']._serialized_end=5071
  _globals['_PERMISSION_PERMISSIONTYPE']._serialized_start=5019
  _globals['_PERMISSION_PERMISSIONTYPE']._serialized_end=5071
  _globals['_WITNESS']._serialized_start=5074
  _globals['_WITNESS']._serialized_end=5255
  _globals['_VOTES']._serialized_start=5257
  _globals['_VOTES']._serialized_end=5351
  _globals['_TXOUTPUT']._serialized_start=5353
  _globals['_TXOUTPUT']._serialized_end=5398
  _globals['_TXINPUT']._serialized_start=5400
  _globals['_TXINPUT']._serialized_end=5520
  _globals['_TXINPUT_RAW']._serialized_start=5471
  _globals['_TXINPUT_RAW']._serialized_end=5520
  _globals['_TXOUTPUTS']._serialized_start=5522
  _globals['_TXOUTPUTS']._serialized_end=5570
  _globals['_RESOURCERECEIPT']._serialized_start=5573
  _globals['_RESOURCERECEIPT']._serialized_end=5816
  _globals['_MARKETORDERDETAIL']._serialized_start=5818
  _globals['_MARKETORDERDETAIL']._serialized_end=5932
  _globals['_TRANSACTION']._serialized_start=5935
  _globals['_TRANSACTION']._serialized_end=8643
  _globals['_TRANSACTION_CONTRACT']._serialized_start=6058
  _globals['_TRANSACTION_CONTRACT']._serialized_end=7394
  _globals['_TRANSACTION_CONTRACT_CONTRACTTYPE']._serialized_start=6234
  _globals['_TRANSACTION_CONTRACT_CONTRACTTYPE']._serialized_end=7394
  _globals['_TRANSACTION_RESULT']._serialized_start=7397
  _globals['_TRANSACTION_RESULT']._serialized_end=8388
  _globals['_TRANSACTION_RESULT_CANCELUNFREEZEV2AMOUNTENTRY']._serialized_start=7969
  _globals['_TRANSACTION_RESULT_CANCELUNFREEZEV2AMOUNTENTRY']._serialized_end=8030
  _globals['_TRANSACTION_RESULT_CODE']._serialized_start=8032
  _globals['_TRANSACTION_RESULT_CODE']._serialized_end=8062
  _globals['_TRANSACTION_RESULT_CONTRACTRESULT']._serialized_start=8065
  _globals['_TRANSACTION_RESULT_CONTRACTRESULT']._serialized_end=8388
  _globals['_TRANSACTION_RAW']._serialized_start=8391
  _globals['_TRANSACTION_RAW']._serialized_end=8643
  _globals['_TRANSACTIONINFO']._serialized_start=8646
  _globals['_TRANSACTIONINFO']._serialized_end=9602
  _globals['_TRANSACTIONINFO_LOG']._serialized_start=9455
  _globals['_TRANSACTIONINFO_LOG']._serialized_end=9507
  _globals['_TRANSACTIONINFO_CANCELUNFREEZEV2AMOUNTENTRY']._serialized_start=7969
  _globals['_TRANSACTIONINFO_CANCELUNFREEZEV2AMOUNTENTRY']._serialized_end=8030
  _globals['_TRANSACTIONINFO_CODE']._serialized_start=8032
  _globals['_TRANSACTIONINFO_CODE']._serialized_end=8062
  _globals['_TRANSACTIONRET']._serialized_start=9604
  _globals['_TRANSACTIONRET']._serialized_end=9717
  _globals['_TRANSACTIONS']._serialized_start=9719
  _globals['_TRANSACTIONS']._serialized_end=9778
  _globals['_BLOCKHEADER']._serialized_start=9781
  _globals['_BLOCKHEADER']._serialized_end=10037
  _globals['_BLOCKHEADER_RAW']._serialized_start=9869
  _globals['_BLOCKHEADER_RAW']._serialized_end=10037
  _globals['_BLOCK']._serialized_start=10039
  _globals['_BLOCK']._serialized_end=10136
  _globals['_CHAININVENTORY']._serialized_start=10138
  _globals['_CHAININVENTORY']._serialized_end=10262
  _globals['_CHAININVENTORY_BLOCKID']._serialized_start=10223
  _globals['_CHAININVENTORY_BLOCKID']._serialized_end=10262
  _globals['_BLOCKINVENTORY']._serialized_start=10265
  _globals['_BLOCKINVENTORY']._serialized_end=10456
  _globals['_BLOCKINVENTORY_BLOCKID']._serialized_start=10223
  _globals['_BLOCKINVENTORY_BLOCKID']._serialized_end=10262
  _globals['_BLOCKINVENTORY_TYPE']._serialized_start=10416
  _globals['_BLOCKINVENTORY_TYPE']._serialized_end=10456
  _globals['_INVENTORY']._serialized_start=10458
  _globals['_INVENTORY']._serialized_end=10568
  _globals['_INVENTORY_INVENTORYTYPE']._serialized_start=10533
  _globals['_INVENTORY_INVENTORYTYPE']._serialized_end=10568
  _globals['_ITEMS']._serialized_start=10571
  _globals['_ITEMS']._serialized_end=10800
  _globals['_ITEMS_ITEMTYPE']._serialized_start=10744
  _globals['_ITEMS_ITEMTYPE']._serialized_end=10800
  _globals['_DYNAMICPROPERTIES']._serialized_start=10802
  _globals['_DYNAMICPROPERTIES']._serialized_end=10854
  _globals['_DISCONNECTMESSAGE']._serialized_start=10856
  _globals['_DISCONNECTMESSAGE']._serialized_end=10913
  _globals['_HELLOMESSAGE']._serialized_start=10916
  _globals['_HELLOMESSAGE']._serialized_end=11303
  _globals['_HELLOMESSAGE_BLOCKID']._serialized_start=10223
  _globals['_HELLOMESSAGE_BLOCKID']._serialized_end=10262
  _globals['_INTERNALTRANSACTION']._serialized_start=11306
  _globals['_INTERNALTRANSACTION']._serialized_end=11561
  _globals['_INTERNALTRANSACTION_CALLVALUEINFO']._serialized_start=11510
  _globals['_INTERNALTRANSACTION_CALLVALUEINFO']._serialized_end=11561
  _globals['_DELEGATEDRESOURCEACCOUNTINDEX']._serialized_start=11563
  _globals['_DELEGATEDRESOURCEACCOUNTINDEX']._serialized_end=11672
  _globals['_NODEINFO']._serialized_start=11675
  _globals['_NODEINFO']._serialized_end=13882
  _globals['_NODEINFO_CHEATWITNESSINFOMAPENTRY']._serialized_start=12089
  _globals['_NODEINFO_CHEATWITNESSINFOMAPENTRY']._serialized_end=12147
  _globals['_NODEINFO_PEERINFO']._serialized_start=12150
  _globals['_NODEINFO_PEERINFO']._serialized_end=12739
  _globals['_NODEINFO_CONFIGNODEINFO']._serialized_start=12742
  _globals['_NODEINFO_CONFIGNODEINFO']._serialized_end=13227
  _globals['_NODEINFO_MACHINEINFO']._serialized_start=13230
  _globals['_NODEINFO_MACHINEINFO']._serialized_end=13882
  _globals['_NODEINFO_MACHINEINFO_MEMORYDESCINFO']._serialized_start=13637
  _globals['_NODEINFO_MACHINEINFO_MEMORYDESCINFO']._serialized_end=13736
  _globals['_NODEINFO_MACHINEINFO_DEADLOCKTHREADINFO']._serialized_start=13739
  _globals['_NODEINFO_MACHINEINFO_DEADLOCKTHREADINFO']._serialized_end=13882
  _globals['_METRICSINFO']._serialized_start=13885
  _globals['_METRICSINFO']._serialized_end=16250
  _globals['_METRICSINFO_NODEINFO']._serialized_start=14066
  _globals['_METRICSINFO_NODEINFO']._serialized_end=14145
  _globals['_METRICSINFO_BLOCKCHAININFO']._serialized_start=14148
  _globals['_METRICSINFO_BLOCKCHAININFO']._serialized_end=14775
  _globals['_METRICSINFO_BLOCKCHAININFO_WITNESS']._serialized_start=14668
  _globals['_METRICSINFO_BLOCKCHAININFO_WITNESS']._serialized_end=14711
  _globals['_METRICSINFO_BLOCKCHAININFO_DUPWITNESS']._serialized_start=14713
  _globals['_METRICSINFO_BLOCKCHAININFO_DUPWITNESS']._serialized_end=14775
  _globals['_METRICSINFO_RATEINFO']._serialized_start=14777
  _globals['_METRICSINFO_RATEINFO']._serialized_end=14894
  _globals['_METRICSINFO_NETINFO']._serialized_start=14897
  _globals['_METRICSINFO_NETINFO']._serialized_end=16250
  _globals['_METRICSINFO_NETINFO_APIINFO']._serialized_start=15431
  _globals['_METRICSINFO_NETINFO_APIINFO']._serialized_end=15833
  _globals['_METRICSINFO_NETINFO_APIINFO_APIDETAILINFO']._serialized_start=15658
  _globals['_METRICSINFO_NETINFO_APIINFO_APIDETAILINFO']._serialized_end=15833
  _globals['_METRICSINFO_NETINFO_DISCONNECTIONDETAILINFO']._serialized_start=15835
  _globals['_METRICSINFO_NETINFO_DISCONNECTIONDETAILINFO']._serialized_end=15891
  _globals['_METRICSINFO_NETINFO_LATENCYINFO']._serialized_start=15894
  _globals['_METRICSINFO_NETINFO_LATENCYINFO']._serialized_end=16250
  _globals['_METRICSINFO_NETINFO_LATENCYINFO_LATENCYDETAILINFO']._serialized_start=16103
  _globals['_METRICSINFO_NETINFO_LATENCYINFO_LATENCYDETAILINFO']._serialized_end=16250
  _globals['_PBFTMESSAGE']._serialized_start=16253
  _globals['_PBFTMESSAGE']._serialized_end=16597
  _globals['_PBFTMESSAGE_RAW']._serialized_start=16333
  _globals['_PBFTMESSAGE_RAW']._serialized_end=16483
  _globals['_PBFTMESSAGE_MSGTYPE']._serialized_start=16485
  _globals['_PBFTMESSAGE_MSGTYPE']._serialized_end=16565
  _globals['_PBFTMESSAGE_DATATYPE']._serialized_start=16567
  _globals['_PBFTMESSAGE_DATATYPE']._serialized_end=16597
  _globals['_PBFTCOMMITRESULT']._serialized_start=16599
  _globals['_PBFTCOMMITRESULT']._serialized_end=16650
  _globals['_SRL']._serialized_start=16652
  _globals['_SRL']._serialized_end=16676
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron_sdk_py/proto/core/contract/account_contract.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'tron_sdk_py/proto/core/contract/account_contract.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tron_sdk_py.proto.core import Tron_pb2 as tron__sdk__py_dot_proto_dot_core_dot_Tron__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6tron_sdk_py/proto/core/contract/account_contract.proto\x12\x08protocol\x1a!tron_sdk_py/proto/core/Tron.proto\"l\n\x15\x41\x63\x63ountCreateContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\x0c\x12#\n\x04type\x18\x03 \x01(\x0e\x32\x15.protocol.AccountType\"D\n\x15\x41\x63\x63ountUpdateContract\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\x0c\x12\x15\n\rowner_address\x18\x02 \x01(\x0c\"A\n\x14SetAccountIdContract\x12\x12\n\naccount_id\x18\x01 \x01(\x0c\x12\x15\n\rowner_address\x18\x02 \x01(\x0c\"\xab\x01\n\x1f\x41\x63\x63ountPermissionUpdateContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12#\n\x05owner\x18\x02 \x01(\x0b\x32\x14.protocol.Permission\x12%\n\x07witness\x18\x03 \x01(\x0b\x32\x14.protocol.Permission\x12%\n\x07\x61\x63tives\x18\x04 \x03(\x0b\x32\x14.protocol.PermissionBE\n\x18org.tron.protos.contractZ)github.com/tronprotocol/grpc-gateway/coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron_sdk_py.proto.core.contract.account_contract_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.tron.protos.contractZ)github.com/tronprotocol/grpc-gateway/core'
  _globals['_ACCOUNTCREATECONTRACT']._serialized_start=103
  _globals['_ACCOUNTCREATECONTRACT']._serialized_end=211
  _globals['_ACCOUNTUPDATECONTRACT']._serialized_start=213
  _globals['_ACCOUNTUPDATECONTRACT']._serialized_end=281
  _globals['_SETACCOUNTIDCONTRACT']._serialized_start=283
  _globals['_SETACCOUNTIDCONTRACT']._serialized_end=348
  _globals['_ACCOUNTPERMISSIONUPDATECONTRACT']._serialized_start=351
  _globals['_ACCOUNTPERMISSIONUPDATECONTRACT']._serialized_end=522
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron_sdk_py/proto/core/contract/market_contract.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'tron_sdk_py/proto/core/contract/market_contract.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5tron_sdk_py/proto/core/contract/market_contract.proto\x12\x08protocol\"\x96\x01\n\x17MarketSellAssetContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x15\n\rsell_token_id\x18\x02 \x01(\x0c\x12\x1b\n\x13sell_token_quantity\x18\x03 \x01(\x03\x12\x14\n\x0c\x62uy_token_id\x18\x04 \x01(\x0c\x12\x1a\n\x12\x62uy_token_quantity\x18\x05 \x01(\x03\"D\n\x19MarketCancelOrderContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x10\n\x08order_id\x18\x02 \x01(\x0c\x42\x45\n\x18org.tron.protos.contractZ)github.com/tronprotocol/grpc-gateway/coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron_sdk_py.proto.core.contract.market_contract_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.tron.protos.contractZ)github.com/tronprotocol/grpc-gateway/core'
  _globals['_MARKETSELLASSETCONTRACT']._serialized_start=68
  _globals['_MARKETSELLASSETCONTRACT']._serialized_end=218
  _globals['_MARKETCANCELORDERCONTRACT']._serialized_start=220
  _globals['_MARKETCANCELORDERCONTRACT']._serialized_end=288
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron_sdk_py/proto/core/contract/asset_issue_contract.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'tron_sdk_py/proto/core/contract/asset_issue_contract.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:tron_sdk_py/proto/core/contract/asset_issue_contract.proto\x12\x08protocol\"\x90\x04\n\x12\x41ssetIssueContract\x12\n\n\x02id\x18) \x01(\t\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\x0c\x12\x0c\n\x04\x61\x62\x62r\x18\x03 \x01(\x0c\x12\x14\n\x0ctotal_supply\x18\x04 \x01(\x03\x12@\n\rfrozen_supply\x18\x05 \x03(\x0b\x32).protocol.AssetIssueContract.FrozenSupply\x12\x0f\n\x07trx_num\x18\x06 \x01(\x05\x12\x11\n\tprecision\x18\x07 \x01(\x05\x12\x0b\n\x03num\x18\x08 \x01(\x05\x12\x12\n\nstart_time\x18\t \x01(\x03\x12\x10\n\x08\x65nd_time\x18\n \x01(\x03\x12\r\n\x05order\x18\x0b \x01(\x03\x12\x12\n\nvote_score\x18\x10 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x14 \x01(\x0c\x12\x0b\n\x03url\x18\x15 \x01(\x0c\x12\x1c\n\x14\x66ree_asset_net_limit\x18\x16 \x01(\x03\x12#\n\x1bpublic_free_asset_net_limit\x18\x17 \x01(\x03\x12#\n\x1bpublic_free_asset_net_usage\x18\x18 \x01(\x03\x12#\n\x1bpublic_latest_free_net_time\x18\x19 \x01(\x03\x1a:\n\x0c\x46rozenSupply\x12\x15\n\rfrozen_amount\x18\x01 \x01(\x03\x12\x13\n\x0b\x66rozen_days\x18\x02 \x01(\x03\"f\n\x15TransferAssetContract\x12\x12\n\nasset_name\x18\x01 \x01(\x0c\x12\x15\n\rowner_address\x18\x02 \x01(\x0c\x12\x12\n\nto_address\x18\x03 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x03\".\n\x15UnfreezeAssetContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\"{\n\x13UpdateAssetContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\x0c\x12\x0b\n\x03url\x18\x03 \x01(\x0c\x12\x11\n\tnew_limit\x18\x04 \x01(\x03\x12\x18\n\x10new_public_limit\x18\x05 \x01(\x03\"n\n\x1dParticipateAssetIssueContract\x12\x15\n\rowner_address\x18\x01 \x01(\x0c\x12\x12\n\nto_address\x18\x02 \x01(\x0c\x12\x12\n\nasset_name\x18\x03 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x03\x42\x45\n\x18org.tron.protos.contractZ)github.com/tronprotocol/grpc-gateway/coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron_sdk_py.proto.core.contract.asset_issue_contract_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.tron.protos.contractZ)github.com/tronprotocol/grpc-gateway/core'
  _globals['_ASSETISSUECONTRACT']._serialized_start=73
  _globals['_ASSETISSUECONTRACT']._serialized_end=601
  _globals['_ASSETISSUECONTRACT_FROZENSUPPLY']._serialized_start=543
  _globals['_ASSETISSUECONTRACT_FROZENSUPPLY']._serialized_end=601
  _globals['_TRANSFERASSETCONTRACT']._serialized_start=603
  _globals['_TRANSFERASSETCONTRACT']._serialized_end=705
  _globals['_UNFREEZEASSETCONTRACT']._serialized_start=707
  _globals['_UNFREEZEASSETCONTRACT']._serialized_end=753
  _globals['_UPDATEASSETCONTRACT']._serialized_start=755
  _globals['_UPDATEASSETCONTRACT']._serialized_end=878
  _globals['_PARTICIPATEASSETISSUECONTRACT']._serialized_start=880
  _globals['_PARTICIPATEASSETISSUECONTRACT']._serialized_end=990
# @@protoc_insertion_point(module_scope)
